@@ -5,6 +5,13 @@
 from syst3m.v1.classes.config import *
 import platform 
 
+# functions.
+def get_argument(id):
+	match = False
+	for i in sys.argv:
+		if id == i: match = True
+		elif match == True: return i
+	return None
 class Defaults(object):
 	def __init__(self):
 
@@ -31,8 +38,10 @@ class Defaults(object):
 		# the source path.
 		executable=None,
 	):
+		id = get_argument("--create-alias")
+		present = "--create-alias" in sys.argv and id == ALIAS
 		path = f"/usr/local/bin/{alias}"
-		if not os.path.exists(path) or '--create-alias' in sys.argv:
+		if present or not os.path.exists(path):
 			file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
 			os.system(f"sudo touch {path}")
 			os.system(f"sudo chmod 755 {path}")
@@ -42,7 +51,7 @@ class Defaults(object):
 			if '--silent' not in sys.argv:
 				print(f'Successfully created alias: {alias}.')
 				print(f"Check out the docs for more info $: {alias} -h")
-		if '--create-alias' in sys.argv:
+		if present:
 			quit()
 	def get_source_path(self, path, back=1):
 		return Formats.FilePath(path).base(back=back)
